const db = require('../../shared/db');

async function createPrices(prices) {
    const query = 'INSERT INTO prices (price, productId) VALUES ?';
    const values = prices.map(price => [price.price, price.productId]);
    await db.query(query, [values]);

}

async function getLastPriceByProductId(productId) {
    const query = 'SELECT price FROM prices WHERE productId = ? ORDER BY createdAt DESC LIMIT 1 OFFSET 1';
    const [rows] = await db.query(query, [productId]);
    return rows.length > 0 ? rows[0].price : null;
}

async function getLastPricesByProductIds(productIds) {
    const query = `
        SELECT p1.productId, p1.price
        FROM prices p1
        JOIN (
            SELECT productId, MAX(createdAt) AS maxCreatedAt
            FROM prices
            WHERE productId IN (?)
            GROUP BY productId
        ) p2 ON p1.productId = p2.productId AND p1.createdAt = p2.maxCreatedAt
    `;
    const [rows] = await db.query(query, [productIds]);
    return rows;
}

module.exports = {
    createPrices,
    getLastPriceByProductId,
    getLastPricesByProductIds,
};